@@ -26,7 +26,8 @@ tab-size = 4
 #include <netdb.h>
 #include <ifaddrs.h>
 #include <net/if.h>
-#include <thread>
+#include <arpa/inet.h> // for inet_ntop()
+
 
 #if !(defined(STATIC_BUILD) && defined(__GLIBC__))
 	#include <pwd.h>
@@ -107,7 +108,7 @@ namespace Shared {
 		if (passwd_path.empty())
 			Logger::warning("Could not read /etc/passwd, will show UID instead of username.");
 
-		coreCount = std::thread::hardware_concurrency();
+		coreCount = sysconf(_SC_NPROCESSORS_ONLN);
 		if (coreCount < 1) {
 			coreCount = sysconf(_SC_NPROCESSORS_CONF);
 			if (coreCount < 1) {
@@ -668,6 +669,9 @@ namespace Cpu {
 		if (Runner::stopping or (no_update and not current_cpu.cpu_percent.at("total").empty())) return current_cpu;
 		auto& cpu = current_cpu;
 
+		if (Config::getB("show_cpu_freq"))
+			cpuHz = get_cpuHz();
+
 		ifstream cread;
 
 		try {
@@ -795,9 +799,6 @@ namespace Cpu {
             else throw std::runtime_error("Cpu::collect() : " + string{e.what()});
 		}
 
-		if (Config::getB("show_cpu_freq"))
-			cpuHz = get_cpuHz();
-
 		if (Config::getB("check_temp") and got_sensors)
 			update_sensors();
 
@@ -926,6 +927,7 @@ namespace Mem {
 
 		//? Get disks stats
 		if (show_disks) {
+			static vector<string> ignore_list;
 			double uptime = system_uptime();
 			auto free_priv = Config::getB("disk_free_priv");
 			try {
@@ -998,7 +1000,7 @@ namespace Mem {
 						diskread >> dev >> mountpoint >> fstype;
 						diskread.ignore(SSmax, '\n');
 
-						if (v_contains(found, mountpoint)) continue;
+						if (v_contains(ignore_list, mountpoint) or v_contains(found, mountpoint)) continue;
 
 						//? Match filter if not empty
 						if (not filter.empty()) {
@@ -1057,6 +1059,7 @@ namespace Mem {
 							}
 						}
 					}
+
 					//? Remove disks no longer mounted or filtered out
 					if (swap_disk and has_swap) found.push_back("swap");
 					for (auto it = disks.begin(); it != disks.end();) {
@@ -1073,11 +1076,14 @@ namespace Mem {
 				diskread.close();
 
 				//? Get disk/partition stats
+				bool new_ignored = false;
 				for (auto& [mountpoint, disk] : disks) {
-					if (std::error_code ec; not fs::exists(mountpoint, ec)) continue;
+					if (std::error_code ec; not fs::exists(mountpoint, ec) or v_contains(ignore_list, mountpoint)) continue;
 					struct statvfs64 vfs;
 					if (statvfs64(mountpoint.c_str(), &vfs) < 0) {
-						Logger::warning("Failed to get disk/partition stats with statvfs() for: " + mountpoint);
+						Logger::warning("Failed to get disk/partition stats for mount \""+ mountpoint + "\" with statvfs64 error code: " + to_string(errno) + ". Ignoring...");
+						ignore_list.push_back(mountpoint);
+						new_ignored = true;
 						continue;
 					}
 					disk.total = vfs.f_blocks * vfs.f_frsize;
@@ -1087,6 +1093,16 @@ namespace Mem {
 					disk.free_percent = 100 - disk.used_percent;
 				}
 
+				//? Remove any problematic disks added to the ignore_list
+				if (new_ignored) {
+					for (auto it = disks.begin(); it != disks.end();) {
+						if (v_contains(ignore_list, it->first))
+							it = disks.erase(it);
+						else
+							it++;
+					}
+				}
+
 				//? Setup disks order in UI and add swap if enabled
 				mem.disks_order.clear();
 				#ifdef SNAPPED
@@ -1374,32 +1390,53 @@ namespace Net {
 				return empty_net;
 			}
 			int family = 0;
-			char ip[NI_MAXHOST];
+			static_assert(INET6_ADDRSTRLEN >= INET_ADDRSTRLEN); // 46 >= 16, compile-time assurance.
+			enum { IPBUFFER_MAXSIZE = INET6_ADDRSTRLEN }; // manually using the known biggest value, guarded by the above static_assert
+			char ip[IPBUFFER_MAXSIZE];
 			interfaces.clear();
 			string ipv4, ipv6;
 
 			//? Iteration over all items in getifaddrs() list
-            for (auto* ifa = if_wrap(); ifa != NULL; ifa = ifa->ifa_next) {
+			for (auto* ifa = if_wrap(); ifa != NULL; ifa = ifa->ifa_next) {
 				if (ifa->ifa_addr == NULL) continue;
 				family = ifa->ifa_addr->sa_family;
 				const auto& iface = ifa->ifa_name;
 
-				//? Get IPv4 address
-				if (family == AF_INET) {
-					if (getnameinfo(ifa->ifa_addr, sizeof(struct sockaddr_in), ip, NI_MAXHOST, NULL, 0, NI_NUMERICHOST) == 0)
-						net[iface].ipv4 = ip;
-				}
-				//? Get IPv6 address
-				else if (family == AF_INET6) {
-					if (getnameinfo(ifa->ifa_addr, sizeof(struct sockaddr_in6), ip, NI_MAXHOST, NULL, 0, NI_NUMERICHOST) == 0)
-						net[iface].ipv6 = ip;
-				}
-
 				//? Update available interfaces vector and get status of interface
 				if (not v_contains(interfaces, iface)) {
 					interfaces.push_back(iface);
 					net[iface].connected = (ifa->ifa_flags & IFF_RUNNING);
+
+					// An interface can have more than one IP of the same family associated with it,
+					// but we pick only the first one to show in the NET box.
+					// Note: Interfaces without any IPv4 and IPv6 set are still valid and monitorable!
+					net[iface].ipv4.clear();
+					net[iface].ipv6.clear();
 				}
+
+
+				//? Get IPv4 address
+				if (family == AF_INET) {
+					if (net[iface].ipv4.empty()) {
+						if (NULL != inet_ntop(family, &(reinterpret_cast<struct sockaddr_in*>(ifa->ifa_addr)->sin_addr), ip, IPBUFFER_MAXSIZE)) {
+							net[iface].ipv4 = ip;
+						} else {
+							int errsv = errno;
+							Logger::error("Net::collect() -> Failed to convert IPv4 to string for iface " + string(iface) + ", errno: " + strerror(errsv));
+						}
+					}
+				}
+				//? Get IPv6 address
+				else if (family == AF_INET6) {
+					if (net[iface].ipv6.empty()) {
+						if (NULL != inet_ntop(family, &(reinterpret_cast<struct sockaddr_in6*>(ifa->ifa_addr)->sin6_addr), ip, IPBUFFER_MAXSIZE)) {
+							net[iface].ipv6 = ip;
+						} else {
+							int errsv = errno;
+							Logger::error("Net::collect() -> Failed to convert IPv6 to string for iface " + string(iface) + ", errno: " + strerror(errsv));
+						}
+					}
+				} //else, ignoring family==AF_PACKET (see man 3 getifaddrs) which is the first one in the `for` loop.
 			}
 
 			//? Get total recieved and transmitted bytes + device address if no ip was found
@@ -1707,6 +1744,7 @@ namespace Proc {
 						getline(pread, r_user, ':');
 						pread.ignore(SSmax, ':');
 						getline(pread, r_uid, ':');
+						if (uid_user.contains(r_uid)) break;
 						uid_user[r_uid] = r_user;
 						pread.ignore(SSmax, '\n');
 					}
@@ -1846,7 +1884,7 @@ namespace Proc {
 								next_x = 19;
 								continue;
 							case 19: //? Nice value
-								new_proc.p_nice = stoull(short_str);
+								new_proc.p_nice = stoll(short_str);
 								continue;
 							case 20: //? Number of threads
 								new_proc.threads = stoull(short_str);
